import { Node } from '..';
/**
 * `Command` objects represent an action that a user is taking on the editor.
 * They capture the semantic "intent" of a user while they edit a document.
 */
export interface Command {
    type: string;
    [key: string]: any;
}
export declare const Command: {
    /**
     * Check if a value is a `Command` object.
     */
    isCommand(value: any): value is Command;
};
/**
 * The `DeleteBackwardCommand` delete's content backward, meaning before the
 * current selection, by a specific `unit` of distance.
 */
export interface DeleteBackwardCommand {
    type: 'delete_backward';
    unit: 'character' | 'word' | 'line' | 'block';
}
/**
 * The `DeleteBackwardCommand` delete's content forward, meaning after the
 * current selection, by a specific `unit` of distance.
 */
export interface DeleteForwardCommand {
    type: 'delete_forward';
    unit: 'character' | 'word' | 'line' | 'block';
}
/**
 * The `DeleteFragmentCommand` delete's the content of the current selection.
 */
export interface DeleteFragmentCommand {
    type: 'delete_fragment';
}
/**
 * The `FormatTextCommand` adds properties to the text nodes in the selection.
 */
export interface FormatTextCommand {
    type: 'format_text';
    properties: Record<string, any>;
}
/**
 * The `InsertBreakCommand` breaks a block in two at the current selection.
 */
export interface InsertBreakCommand {
    type: 'insert_break';
}
/**
 * The `InsertFragmentCommand` inserts a list of nodes at the current selection.
 */
export interface InsertFragmentCommand {
    type: 'insert_fragment';
    fragment: Node[];
}
/**
 * The `InsertNodeCommand` inserts a node at the current selection.
 */
export interface InsertNodeCommand {
    type: 'insert_node';
    node: Node;
}
/**
 * The `InsertTextCommand` inserts a string of text at the current selection.
 */
export interface InsertTextCommand {
    type: 'insert_text';
    text: string;
}
/**
 * The `CoreCommand` union is a set of all of the commands that are recognized
 * by Slate's "core" out of the box.
 */
export declare type CoreCommand = DeleteBackwardCommand | DeleteForwardCommand | DeleteFragmentCommand | FormatTextCommand | InsertBreakCommand | InsertFragmentCommand | InsertNodeCommand | InsertTextCommand;
export declare const CoreCommand: {
    /**
     * Check if a value is a `CoreCommand` object.
     */
    isCoreCommand(value: any): value is CoreCommand;
};
//# sourceMappingURL=command.d.ts.map